@@ -25,11 +25,11 @@ from tendenci.core.categories.models import CategoryItem
 
 
 def file_directory(instance, filename):
-    filename = re.sub(r'[^a-zA-Z0-9._]+', '-', filename)
+    filename = re.sub(r'[^a-z0-9._]+', '_', filename.lower())
     uuid_hex = uuid.uuid1().get_hex()[:8]
 
     if instance.content_type:
-        content_type = re.sub(r'[^a-zA-Z0-9._]+', '-', unicode(instance.content_type))
+        content_type = re.sub(r'[^a-zA-Z0-9._]+', '_', unicode(instance.content_type.app_label))
         return 'files/%s/%s/%s' % (content_type, uuid_hex, filename)
 
     return 'files/files/%s/%s' % (uuid_hex, filename)
